@@ -1,11 +1,8 @@
-#line 1 "inc/Module/Install/RTx.pm - /Library/Perl/5.8.5/Module/Install/RTx.pm"
-# $File: //member/autrijus/Module-Install-RTx/lib/Module/Install/RTx.pm $ $Author: autrijus $
-# $Revision: #17 $ $Change: 10722 $ $DateTime: 2004/05/31 18:38:57 $ vim: expandtab shiftwidth=4
-
+#line 1 "inc/Module/Install/RTx.pm - /usr/local/lib/perl5/site_perl/5.8.5/Module/Install/RTx.pm"
 package Module::Install::RTx;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
-$Module::Install::RTx::VERSION = '0.08';
+$Module::Install::RTx::VERSION = '0.11';
 
 use strict;
 use FindBin;
@@ -30,7 +27,7 @@ sub RTx {
     my $prefix = $ENV{PREFIX};
     @ARGV = grep { /PREFIX=(.*)/ ? (($prefix = $1), 0) : 1 } @ARGV;
 
-    if ($prefix) {
+    if ($prefix and -e "$prefix/lib/RT.pm") {
         $RT::LocalPath = $prefix;
         $INC{'RT.pm'} = "$RT::LocalPath/lib/RT.pm";
     }
@@ -128,7 +125,7 @@ dropdb ::
     if (%has_etc) {
         $self->load('RTxInitDB');
         print "For first-time installation, type 'make initdb'.\n";
-        my $initdb = "initdb ::\n";
+        my $initdb = '';
         $initdb .= <<"." if $has_etc{schema};
 \t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" -Minc::Module::Install -e"RTxInitDB(qw(schema))"
 .
@@ -138,7 +135,8 @@ dropdb ::
         $initdb .= <<"." if $has_etc{initialdata};
 \t\$(NOECHO) \$(PERL) -Ilib -I"$lib_path" -Minc::Module::Install -e"RTxInitDB(qw(insert))"
 .
-        $self->postamble("$initdb\n");
+        $self->postamble("initdb ::\n$initdb\n");
+        $self->postamble("initialize-database ::\n$initdb\n");
     }
 }
 
@@ -155,4 +153,6 @@ sub RTxInit {
 
 __END__
 
-#line 234
+#line 221
+
+#line 242
